@@ -67,7 +67,6 @@ qx.Class.define("callbackery.ui.plugin.Action", {
         selection: {}
     },
     members: {
-        _timerId : null,
         _cfg: null,
         _tableMenu: null,
         _defaultAction: null,
@@ -150,12 +149,15 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                         var timer = qx.util.TimerManager.getInstance();
                         var timerId;
                         this.addListener('appear',function(){
-                            timerId = this._timerId = timer.start(function(){
-                                this.fireDataEvent('actionResponse', {action: 'reloadStatus'});
+                            timerId = timer.start(function(){
+                                this.fireDataEvent('actionResponse',{action: 'reloadStatus'});
                             }, btCfg.interval * 1000, this);
                         }, this);
                         this.addListener('disappear',function(){
-                            timer.stop(timerId);
+                            if (timerId) {
+                                timer.stop(timerId);
+                                timerId = null;
+                            }
                         }, this);
                         break;
                     case 'autoSubmit':
@@ -164,7 +166,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                         this.addListener('appear',function(){
                             var key = btCfg.key;
                             var that = this;
-                            autoTimerId = this._timerId = autoTimer.start(function(){
+                            autoTimerId = autoTimer.start(function(){
                                 var formData = getFormData();
                                 callbackery.data.Server.getInstance().callAsyncSmartBusy(function(ret){
                                     that.fireDataEvent('actionResponse',ret || {});
@@ -172,7 +174,10 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                             }, btCfg.interval * 1000, this);
                         }, this);
                         this.addListener('disappear',function(){
-                            autoTimer.stop(autoTimerId);
+                            if (autoTimerId) {
+                                autoTimer.stop(autoTimerId);
+                                autoTimerId = null;
+                            }
                         }, this);
                         break;
                     case 'upload':
@@ -184,6 +189,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                     default:
                         this.debug('Invalid execute action:' + btCfg.action);
                 }
+
                 var action = function(){
                     var that = this;
                     if (! button.isEnabled()) {
@@ -233,7 +239,6 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                 return;
                             }
                             var key = btCfg.key;
-                            var that = this;
                             callbackery.data.Server.getInstance().callAsyncSmart(function(cookie){
                                 var iframe = new qx.ui.embed.Iframe().set({
                                     width: 100,
@@ -268,9 +273,6 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                             },'getSessionCookie');
                             break;
                         case 'cancel':
-                            if (this._timerId) {
-                                qx.util.TimerManager.getInstance().stop(this._timerId);
-                            }
                             this.fireDataEvent('actionResponse',{action: 'cancel'});
                             break;
                         case 'wizzard':
@@ -297,7 +299,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                             }
                             var popup = new callbackery.ui.Popup(btCfg,getFormData);
 
-                            var appRoot = this.getApplicationRoot();
+                            var appRoot = that.getApplicationRoot();
                     
                             popup.addListenerOnce('close',function(){
                                 // wait for stuff to happen before we rush into
@@ -306,21 +308,21 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                                     appRoot.remove(popup);
                                     popup.dispose();
                                     this.fireEvent('popupClosed');
-                                },this,100);
+                                },that,100);
                                 if (!(btCfg.options && btCfg.options.noReload)){
                                     this.fireDataEvent('actionResponse',{action: ( btCfg.options && btCfg.options.reloadStatusOnClose ) ? 'reloadStatus' : 'reload'});
                                 }
-                            },this);
+                            },that);
                             popup.open();
                             break;
                         case 'logout':
-                            this.fireDataEvent('actionResponse',{action: 'logout'});
+                            that.fireDataEvent('actionResponse',{action: 'logout'});
                             break;
 
                         default:
                             this.debug('Invalid execute action:' + btCfg.action);
                     }
-                }; // var action = function()
+                }; // var action = function() { ... };
 
                 if (btCfg.defaultAction){
                     this._defaultAction = action;
